@@ -5,7 +5,7 @@ use strict;
 use Exporter ();
 use Scalar::Util qw(isvstring reftype);
 use vars qw ($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS @REGEXS);
-$VERSION     = "0.53_03";
+$VERSION     = "0.56_02";
 $VERSION     = eval $VERSION;
 @ISA         = qw (Exporter);
 #Give a hoot don't pollute, do not export more than needed by default
@@ -20,8 +20,6 @@ push @REGEXS, qr/
 	(?:(\d+)\.?){1,}
 	/x;
 
-local $^W; # shut up the 'redefined' warning for UNIVERSAL::VERSION
-
 use overload (
     '+0'   => \&numify,
     '""'   => \&stringify,
@@ -388,4 +386,37 @@ sub _verify {
     }
 }
 
+local $^W; # shut up the 'redefined' warning for UNIVERSAL::VERSION
+no warnings 'redefine';
+
+package UNIVERSAL;
+
+sub VERSION {
+    my ($obj, $req) = @_;
+    my $class = ref($obj) || $obj;
+    no strict 'refs';
+    eval "require $class" unless %{"$class\::"}; # already existing
+    die "$class defines neither package nor VERSION--version check failed"
+        if $@ or not %{"$class\::"};
+    
+    my $version = eval "\$$class\::VERSION";
+    die "$class does not define \$$class\::VERSION--version check failed"
+        unless defined $version;
+
+    $version = version::vpp->new($version);
+
+    if ( defined $req ) {
+	$req = version::vpp->new($req);
+
+	die sprintf ("%s version %s (%s) required--".
+                 "this is only version %s (%s)", $class, 
+		 $req->numify, $req->normal,
+		 $version->numify, $version->normal)
+	    if ( $req > $version ); 
+    }
+
+    return $version->numify;
+}
+
+
 1; #this line is important and will help the module return a true value
